@@ -33,6 +33,8 @@ class Intent(object):
 
     :param name: Name to identify the intent.
     :type name: (optional) str
+    :param generated_by: Name of the generator used to generate this object.
+    :type generated_by: (optional) str
     :param slots: List of slots within the intent.
     :type slots: (optional) list[ask_smapi_model.v1.skill.interaction_model.slot_definition.SlotDefinition]
     :param samples: Phrases the user can speak e.g. to trigger an intent or provide value for a slot elicitation.
@@ -41,23 +43,27 @@ class Intent(object):
     """
     deserialized_types = {
         'name': 'str',
+        'generated_by': 'str',
         'slots': 'list[ask_smapi_model.v1.skill.interaction_model.slot_definition.SlotDefinition]',
         'samples': 'list[str]'
     }  # type: Dict
 
     attribute_map = {
         'name': 'name',
+        'generated_by': 'generatedBy',
         'slots': 'slots',
         'samples': 'samples'
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, name=None, slots=None, samples=None):
-        # type: (Optional[str], Optional[List[SlotDefinition_fa94ac3]], Optional[List[object]]) -> None
+    def __init__(self, name=None, generated_by=None, slots=None, samples=None):
+        # type: (Optional[str], Optional[str], Optional[List[SlotDefinition_fa94ac3]], Optional[List[object]]) -> None
         """The set of intents your service can accept and process.
 
         :param name: Name to identify the intent.
         :type name: (optional) str
+        :param generated_by: Name of the generator used to generate this object.
+        :type generated_by: (optional) str
         :param slots: List of slots within the intent.
         :type slots: (optional) list[ask_smapi_model.v1.skill.interaction_model.slot_definition.SlotDefinition]
         :param samples: Phrases the user can speak e.g. to trigger an intent or provide value for a slot elicitation.
@@ -66,6 +72,7 @@ class Intent(object):
         self.__discriminator_value = None  # type: str
 
         self.name = name
+        self.generated_by = generated_by
         self.slots = slots
         self.samples = samples
 
